#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/5/3 上午11:01
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : zookeeper
# @File    : app_music
# @Contact : guangze.yu@foxmail.com
"""

# zookeeper config
zookeeper_host = '47.100.225.82:2181'
