#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/5/3 上午11:00
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : rabbitmq
# @File    : app_music
# @Contact : guangze.yu@foxmail.com
"""

# pika config
pika_host = '47.100.225.82'
pika_port = 5672
virtual_host = '/'
pika_username = 'admin'
pika_password = 'Root1q2w'
