#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/5/4 下午1:24
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : __init__
# @File    : app_music
# @Contact : guangze.yu@foxmail.com
"""